@@ -11,7 +11,7 @@ use Exporter;
 our @ISA       = qw(Exporter);
 our @EXPORT_OK = qw(extract_image_links);
 
-our $VERSION = '0.45'; # VERSION
+our $VERSION = '0.46'; # VERSION
 
 our %SPEC;
 
@@ -76,22 +76,42 @@ sub extract_image_links {
 
 =pod
 
+=encoding utf-8
+
 =head1 NAME
 
 SHARYANTO::HTML::Extract::ImageLinks - Extract image links from HTML document
 
 =head1 VERSION
 
-version 0.45
+version 0.46
 
 =head1 FUNCTIONS
 
 None are exported by default, but they are exportable.
 
 
-=head2 extract_image_links() -> [status, msg, result, meta]
+None are exported by default, but they are exportable.
 
-No arguments.
+=head2 extract_image_links(%args) -> [status, msg, result, meta]
+
+Extract image links from HTML document.
+
+Either specify either url, html.
+
+Arguments ('*' denotes required arguments):
+
+=over 4
+
+=item * B<base> => I<str>
+
+base URL for images.
+
+=item * B<html>* => I<str>
+
+HTML document to extract from.
+
+=back
 
 Return value:
 
@@ -108,6 +128,8 @@ This software is copyright (c) 2013 by Steven Haryanto.
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
 
+=head1 DESCRIPTION
+
 =cut
 
 
